[polypaudio-commits] r844 - in /trunk/src: polyp/thread-mainloop.c polyp/thread-mainloop.h tests/thread-mainloop-test.c

svnmailer-noreply at 0pointer.de svnmailer-noreply at 0pointer.de
Thu May 11 06:01:24 PDT 2006


Author: lennart
Date: Thu May 11 15:01:24 2006
New Revision: 844

URL: http://0pointer.de/cgi-bin/viewcvs.cgi?rev=844&root=polypaudio&view=rev
Log:
split of signal releasing into its own function and name it pa_threaded_mainloop_accept()

Modified:
    trunk/src/polyp/thread-mainloop.c
    trunk/src/polyp/thread-mainloop.h
    trunk/src/tests/thread-mainloop-test.c

Modified: trunk/src/polyp/thread-mainloop.c
URL: http://0pointer.de/cgi-bin/viewcvs.cgi/trunk/src/polyp/thread-mainloop.c?rev=844&root=polypaudio&r1=843&r2=844&view=diff
==============================================================================
--- trunk/src/polyp/thread-mainloop.c (original)
+++ trunk/src/polyp/thread-mainloop.c Thu May 11 15:01:24 2006
@@ -51,7 +51,7 @@
     pthread_t thread_id;
     pthread_mutex_t mutex;
     int n_waiting;
-    pthread_cond_t cond, release_cond;
+    pthread_cond_t cond, accept_cond;
     int thread_running;
 };
 
@@ -105,7 +105,7 @@
     pthread_mutexattr_destroy(&a);
     
     pthread_cond_init(&m->cond, NULL);
-    pthread_cond_init(&m->release_cond, NULL);
+    pthread_cond_init(&m->accept_cond, NULL);
     m->thread_running = 0;
     m->n_waiting = 0;
 
@@ -126,7 +126,7 @@
 
     pthread_mutex_destroy(&m->mutex);
     pthread_cond_destroy(&m->cond);
-    pthread_cond_destroy(&m->release_cond);
+    pthread_cond_destroy(&m->accept_cond);
     
     pa_xfree(m);
 }
@@ -187,13 +187,13 @@
     pthread_mutex_unlock(&m->mutex);
 }
 
-void pa_threaded_mainloop_signal(pa_threaded_mainloop *m, int wait_for_release) {
+void pa_threaded_mainloop_signal(pa_threaded_mainloop *m, int wait_for_accept) {
     assert(m);
     
     pthread_cond_broadcast(&m->cond);
 
-    if (wait_for_release && m->n_waiting > 0)
-        pthread_cond_wait(&m->release_cond, &m->mutex);
+    if (wait_for_accept && m->n_waiting > 0)
+        pthread_cond_wait(&m->accept_cond, &m->mutex);
 }
 
 void pa_threaded_mainloop_wait(pa_threaded_mainloop *m) {
@@ -206,7 +206,16 @@
     pthread_cond_wait(&m->cond, &m->mutex);
     assert(m->n_waiting > 0);
     m->n_waiting --;
-    pthread_cond_signal(&m->release_cond);
+    pthread_cond_signal(&m->accept_cond);
+}
+
+void pa_threaded_mainloop_accept(pa_threaded_mainloop *m) {
+    assert(m);
+    
+    /* Make sure that this function is not called from the helper thread */
+    assert(!m->thread_running || !pthread_equal(pthread_self(), m->thread_id));
+
+    pthread_cond_signal(&m->accept_cond);
 }
 
 int pa_threaded_mainloop_get_retval(pa_threaded_mainloop *m) {

Modified: trunk/src/polyp/thread-mainloop.h
URL: http://0pointer.de/cgi-bin/viewcvs.cgi/trunk/src/polyp/thread-mainloop.h?rev=844&root=polypaudio&r1=843&r2=844&view=diff
==============================================================================
--- trunk/src/tests/thread-mainloop-test.c (original)
+++ trunk/src/tests/thread-mainloop-test.c Thu May 11 15:01:24 2006
@@ -59,7 +59,9 @@
     fprintf(stderr, "waiting 5s (signal)\n");
     pa_threaded_mainloop_wait(m);
     fprintf(stderr, "wait completed\n");
-
+    pa_threaded_mainloop_accept(m);
+    fprintf(stderr, "signal accepted\n");
+    
     pa_threaded_mainloop_unlock(m);
     
     fprintf(stderr, "waiting 5s (sleep)\n");




More information about the pulseaudio-commits mailing list
--- trunk/src/polyp/thread-mainloop.h (original)
+++ trunk/src/polyp/thread-mainloop.h Thu May 11 15:01:24 2006
@@ -67,9 +67,12 @@
 /** Signal all threads waiting for a signalling event in
  * pa_threaded_mainloop_wait(). If wait_for_release is non-zero, do
  * not return before the signal was accepted by a
  * pa_threaded_mainloop_wait() call. While waiting for that condition
  * the event loop object is unlocked. */
-void pa_threaded_mainloop_signal(pa_threaded_mainloop *m, int wait_for_release);
+void pa_threaded_mainloop_signal(pa_threaded_mainloop *m, int wait_for_accept);
+
+/** Accept a signal from the event thread issued with pa_threaded_mainloop_signal() */
+void pa_threaded_mainloop_accept(pa_threaded_mainloop *m);
 
 /** Return the return value as specified with the main loop's quit() routine. */
 int pa_threaded_mainloop_get_retval(pa_threaded_mainloop *m);
@@ -67,9 +67,12 @@
  * pa_threaded_mainloop_wait(). If wait_for_release is non-zero, do
  * not return before the signal was accepted by a
- * pa_threaded_mainloop_wait() call. While waiting for that condition
+ * pa_threaded_mainloop_accept() call. While waiting for that condition
  * the event loop object is unlocked. */

Modified: trunk/src/tests/thread-mainloop-test.c
URL: http://0pointer.de/cgi-bin/viewcvs.cgi/trunk/src/tests/thread-mainloop-test.c?rev=844&root=polypaudio&r1=843&r2=844&view=diff
==============================================================================